@@ -14,8 +14,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/libadmin/test/pts.c,v 1.5.14.1 2007/10/31 04:09:31 shadow Exp $");
+#include <roken.h>
 
 #include "pts.h"
 
@@ -124,8 +123,8 @@ DoPtsGroupCreate(struct cmd_syndesc *as, void *arock)
 {
     typedef enum { OWNER, GROUP } DoPtsGroupCreate_parm_t;
     afs_status_t st = 0;
-    const char *owner = as->parms[OWNER].items->data;
-    const char *group = as->parms[GROUP].items->data;
+    char *owner = as->parms[OWNER].items->data;
+    char *group = as->parms[GROUP].items->data;
     int new_group_id;
 
     if (!pts_GroupCreate(cellHandle, group, owner, &new_group_id, &st)) {
@@ -280,7 +279,7 @@ DoPtsGroupRename(struct cmd_syndesc *as, void *arock)
     typedef enum { GROUP, NEWNAME } DoPtsGroupRename_parm_t;
     afs_status_t st = 0;
     const char *group = as->parms[GROUP].items->data;
-    const char *new_name = as->parms[NEWNAME].items->data;
+    char *new_name = as->parms[NEWNAME].items->data;
 
     if (!pts_GroupRename(cellHandle, group, new_name, &st)) {
 	ERR_ST_EXT("pts_GroupRename", st);
@@ -327,7 +326,7 @@ DoPtsUserCreate(struct cmd_syndesc *as, void *arock)
 {
     typedef enum { USER } DoPtsUserCreate_parm_t;
     afs_status_t st = 0;
-    const char *user = as->parms[USER].items->data;
+    char *user = as->parms[USER].items->data;
     int new_user_id;
 
     if (!pts_UserCreate(cellHandle, user, &new_user_id, &st)) {
@@ -405,7 +404,7 @@ DoPtsUserRename(struct cmd_syndesc *as, void *arock)
     typedef enum { USER, NEWNAME } DoPtsUserRename_parm_t;
     afs_status_t st = 0;
     const char *user = as->parms[USER].items->data;
-    const char *new_name = as->parms[NEWNAME].items->data;
+    char *new_name = as->parms[NEWNAME].items->data;
 
     if (!pts_UserRename(cellHandle, user, new_name, &st)) {
 	ERR_ST_EXT("pts_UserRename", st);
@@ -423,7 +422,6 @@ DoPtsUserModify(struct cmd_syndesc *as, void *arock)
     afs_status_t st = 0;
     const char *user = as->parms[USER].items->data;
     pts_UserUpdateEntry_t entry;
-    int have_quota = 0;
     int have_list_status_perm = 0;
     int have_list_groups_owned_perm = 0;
     int have_list_membership_perm = 0;
@@ -434,7 +432,6 @@ DoPtsUserModify(struct cmd_syndesc *as, void *arock)
 	entry.groupCreationQuota =
 	    GetIntFromString(as->parms[GROUPQUOTA].items->data, "bad quota");
 	entry.flag = PTS_USER_UPDATE_GROUP_CREATE_QUOTA;
-	have_quota = 1;
     }
 
     if (as->parms[LISTSTATUS].items) {
